==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/mpdstatus.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MPDSTATUS_H
#define MPDSTATUS_H

#include <QString>
#include "libmpdclient.h"

class MPDStatus {
private:
	int m_volume, m_repeat, m_random, m_playlistLength, m_state,
	m_crossfade, m_song, m_songid, m_elapsedTime, m_totalTime,
	m_bitRate, m_bits, m_channels, m_updatingDb;
	long long m_playlist;
	unsigned int m_sampleRate;
	QString m_error;

public:
	MPDStatus() :
			m_volume(0),
			m_repeat(0),
			m_random(0),
			m_playlistLength(0),
			m_state(0),
			m_crossfade(0),
			m_song(-1),
			m_songid(-1),
			m_elapsedTime(0),
			m_totalTime(0),
			m_bitRate(0),
			m_bits(0),
			m_channels(0),
			m_updatingDb(0),
			m_playlist(0),
			m_sampleRate(0),
	m_error(QString::null) {}

	MPDStatus(mpd_Status *s) :
			m_volume(s->volume),
			m_repeat(s->repeat),
			m_random(s->random),
			m_playlistLength(s->playlistLength),
			m_state(s->state),
			m_crossfade(s->crossfade),
			m_song(s->song),
			m_songid(s->songid),
			m_elapsedTime(s->elapsedTime),
			m_totalTime(s->totalTime),
			m_bitRate(s->bitRate),
			m_bits(s->bits),
			m_channels(s->channels),
			m_updatingDb(s->updatingDb),
			m_playlist(s->playlist),
			m_sampleRate(s->sampleRate),
	m_error(QString::fromUtf8(s->error)) {}

	int volume() {
		return m_volume;
	}
	int repeat() {
		return m_repeat;
	}
	int random() {
		return m_random;
	}
	int playlistLength() {
		return m_playlistLength;
	}
	int state() {
		return m_state;
	}
	int crossfade() {
		return m_crossfade;
	}
	int song() {
		return m_song;
	}
	int songid() {
		return m_songid;
	}
	int elapsedTime() {
		return m_elapsedTime;
	}
	void setElapsedTime(int time) {
		m_elapsedTime = time;
	}
	int totalTime() {
		return m_totalTime;
	}
	int bitRate() {
		return m_bitRate;
	}
	int bits() {
		return m_bits;
	}
	int channels() {
		return m_channels;
	}
	int updatingDb() {
		return m_updatingDb;
	}
	long long playlist() {
		return m_playlist;
	}
	unsigned int sampleRate() {
		return m_sampleRate;
	}
	QString error() {
		return m_error;
	}
};

#endif

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/mpdstatus.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MPDSTATUS_H
#define MPDSTATUS_H

#include <QString>
#include "libmpdclient.h"

class MPDStatus {
private:
	class MPDStatusPrivate *d;

public:
	MPDStatus();
	MPDStatus(mpd_Status *);
	MPDStatus(const MPDStatus &);
	~MPDStatus();
	int volume() const;
	int repeat() const;
	int random() const;
	int playlistLength() const;
	int state() const;
	int crossfade() const;
	int song() const;
	int songid() const;
	int elapsedTime() const;
	void setElapsedTime(int time);
	int totalTime() const;
	int bitRate() const;
	int bits() const;
	int channels() const;
	int updatingDb() const;
	long long playlist() const;
	unsigned int sampleRate() const;
	QString error() const;
	MPDStatus &operator=(const MPDStatus &);
};

#endif
